package com.allmycode.p04_02_02

import android.content.Intent
import android.graphics.Bitmap
import android.net.Uri
import android.os.Bundle
import android.view.View
import android.webkit.WebSettings
import android.webkit.WebView
import android.webkit.WebViewClient
import android.widget.RadioButton
import androidx.appcompat.app.AppCompatActivity
import com.facebook.CallbackManager
import com.facebook.FacebookCallback
import com.facebook.FacebookException
import com.facebook.login.LoginManager
import com.facebook.share.Sharer
import com.facebook.share.model.ShareLinkContent
import com.facebook.share.widget.ShareDialog
import kotlinx.android.synthetic.main.activity_main.*

class MainActivity : AppCompatActivity() {
    var callbackManager: CallbackManager? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        val mySettings: WebSettings = webView.settings
        mySettings.setAppCacheEnabled(true)
        mySettings.cacheMode = WebSettings.LOAD_CACHE_ELSE_NETWORK
        mySettings.javaScriptEnabled = true
        mySettings.loadWithOverviewMode = true

        webView.webViewClient = object : WebViewClient() {
            override fun onPageStarted(
                view: WebView?,
                url: String?,
                favicon: Bitmap?
            ) {
                super.onPageStarted(view, url, favicon)
                progressBar.visibility = View.VISIBLE
            }

            override fun onPageFinished(view: WebView?, url: String?) {
                super.onPageFinished(view, url)
                progressBar.visibility = View.GONE
            }
        }

        urlRadioGroup.setOnCheckedChangeListener { _, checkedId ->
            webView.loadUrl(getUrlString(checkedId))
        }

        postButton.setOnClickListener {
            val shareDialog = ShareDialog(this)

            callbackManager = CallbackManager.Factory.create()
            shareDialog.registerCallback(
                callbackManager,
                object : FacebookCallback<Sharer.Result?> {
                    override fun onSuccess(result: Sharer.Result?) {
                        findViewById<RadioButton>(urlRadioGroup
                            .checkedRadioButtonId).isEnabled = false
                    }

                    override fun onCancel() {
                    }

                    override fun onError(error: FacebookException) {
                    }
                })

            if (ShareDialog.canShow(ShareLinkContent::class.java)) {
                val linkContent = ShareLinkContent.Builder()
                    .setContentUrl(Uri.parse(getUrlString
                            (urlRadioGroup.checkedRadioButtonId))
                    ).build()
                shareDialog.show(linkContent)
            }
        }

        logoutButton.setOnClickListener {
            LoginManager.getInstance().logOut()
            resetActivityScreen()
        }
    }

    private fun getUrlString(checkedId: Int): String? {
        return when (checkedId) {
            R.id.dummies_home -> getString(R.string.dummies_home_url)
            R.id.dummies_store -> getString(R.string.dummies_store_url)
            R.id.dummies_android ->
                getString(R.string.dummies_android_url)
            else -> ""
        }
    }

    override fun onActivityResult(
        requestCode: Int,
        resultCode: Int,
        data: Intent?
    ) {
        super.onActivityResult(requestCode, resultCode, data)
        callbackManager!!.onActivityResult(
            requestCode,
            resultCode,
            data
        )
    }

    private fun resetActivityScreen() {
        urlRadioGroup.clearCheck()
        dummies_home.isEnabled = true
        dummies_store.isEnabled = true
        dummies_android.isEnabled = true
        webView.loadUrl("about:blank")
    }
}

